@@ -26,7 +26,7 @@ https://github.com/kellyjonbrazil/jc/tree/master/docs
 
 > Replace `<full_version_number>` - e.g. `1.18.0`:
 
-Specific versions can also be selected by tag in the branch Github dropdown
+Specific versions can also be selected by tag in the Github branch dropdown
 menu.
 
 ## Usage Example
@@ -60,7 +60,7 @@ Use `help(jc.lib)` for details.
 
     parse(
         parser_module_name: str,
-        data: str | Iterable
+        data: str | bytes | Iterable
     ) -> dict | list[dict] | Iterable[dict]
 
 High-level API to easily access the parser. This API will find both
