@@ -14,7 +14,7 @@ from .lib import (__version__, parser_info, all_parser_info, parsers,
                   _get_parser, _parser_is_streaming, standard_parser_mod_list,
                   plugin_parser_mod_list, streaming_parser_mod_list)
 from . import utils
-from .cli_data import long_options_map
+from .cli_data import long_options_map, new_pygments_colors, old_pygments_colors
 from .shell_completions import bash_completion, zsh_completion
 from . import tracebackplus
 from .exceptions import LibraryNotInstalled, ParseError
@@ -48,43 +48,9 @@ class info():
 # startswith is sufficient and avoids potential exceptions from split and int.
 if PYGMENTS_INSTALLED:
     if pygments.__version__.startswith('2.3.'):
-        PYGMENT_COLOR = {
-            'black': '#ansiblack',
-            'red': '#ansidarkred',
-            'green': '#ansidarkgreen',
-            'yellow': '#ansibrown',
-            'blue': '#ansidarkblue',
-            'magenta': '#ansipurple',
-            'cyan': '#ansiteal',
-            'gray': '#ansilightgray',
-            'brightblack': '#ansidarkgray',
-            'brightred': '#ansired',
-            'brightgreen': '#ansigreen',
-            'brightyellow': '#ansiyellow',
-            'brightblue': '#ansiblue',
-            'brightmagenta': '#ansifuchsia',
-            'brightcyan': '#ansiturquoise',
-            'white': '#ansiwhite',
-        }
+        PYGMENT_COLOR = old_pygments_colors
     else:
-        PYGMENT_COLOR = {
-            'black': 'ansiblack',
-            'red': 'ansired',
-            'green': 'ansigreen',
-            'yellow': 'ansiyellow',
-            'blue': 'ansiblue',
-            'magenta': 'ansimagenta',
-            'cyan': 'ansicyan',
-            'gray': 'ansigray',
-            'brightblack': 'ansibrightblack',
-            'brightred': 'ansibrightred',
-            'brightgreen': 'ansibrightgreen',
-            'brightyellow': 'ansibrightyellow',
-            'brightblue': 'ansibrightblue',
-            'brightmagenta': 'ansibrightmagenta',
-            'brightcyan': 'ansibrightcyan',
-            'white': 'ansiwhite',
-        }
+        PYGMENT_COLOR = new_pygments_colors
 
 
 def set_env_colors(env_colors=None):
@@ -259,9 +225,11 @@ def help_doc(options):
                 f'Compatibility:  {compatible}\n\n'\
                 f'Version {version} by {author} ({author_email})\n'
 
-            return doc_text
+            utils._safe_pager(doc_text)
+            return
 
-    return helptext()
+    utils._safe_print(helptext())
+    return
 
 
 def versiontext():
@@ -538,7 +506,7 @@ def main():
         sys.exit(0)
 
     if help_me:
-        utils._safe_print(help_doc(sys.argv))
+        help_doc(sys.argv)
         sys.exit(0)
 
     if version_info:
@@ -622,7 +590,7 @@ def main():
     try:
         # differentiate between regular and streaming parsers
 
-        # streaming
+        # streaming (only supports UTF-8 string data for now)
         if _parser_is_streaming(parser):
             result = parser.parse(sys.stdin,
                                   raw=raw,
@@ -639,9 +607,17 @@ def main():
 
             sys.exit(combined_exit_code(magic_exit_code, 0))
 
-        # regular
+        # regular (supports binary and UTF-8 string data)
         else:
-            data = magic_stdout or sys.stdin.read()
+            data = magic_stdout or sys.stdin.buffer.read()
+
+            # convert to UTF-8, if possible. Otherwise, leave as bytes
+            try:
+                if isinstance(data, bytes):
+                    data = data.decode('utf-8')
+            except UnicodeDecodeError:
+                pass
+
             result = parser.parse(data,
                                   raw=raw,
                                   quiet=quiet)
